% przysiad_gui.m 
%
% AGH Akademia Grniczo-Hutnicza w Krakowie
% Laboratorium Biocybernetyki
%
% Wprowadzenie do modelowania cybernetycznego 
% systemw biologicznych oraz ich symulacji w rodowisku MATLAB
%---------------------------------------------------------------------
% Wykresy supkowe ilustruj zmiany napre w koci udowej czowieka 
% w trakcie przysiadu
function przysiad_gui(arg)

% Ograniczenia wartosci parametrow modelu:
ogr.M_min = 10;   ogr.M_max = 200;
ogr.l_min = 5;    ogr.l_max = 50;
ogr.d_z_min = 1;  ogr.d_z_max = 10;
ogr.d_w_min = 0;  ogr.d_w_max = 99;  

% Wspolrzedne modelu w okienku
wsp_modelu.stopa_x = 0.4; wsp_modelu.stopa_y = 0;
wsp_modelu.s = 0.15;
wsp_modelu.h = 0.8;
wsp_modelu.r = 70;
wsp_modelu.g = 0.12;
wsp_modelu.zx = -0.7;  wsp_modelu.zy = 0;  % wspolrzedne slupkow wykresu zginania
wsp_modelu.sx = -1.3;  wsp_modelu.sy = 0;  % wspolrzedne slupkow wykresu sciskania
wsp_modelu.skala = 1e-7;                   % wsp. skali naprezen   
wsp_modelu.y_suw_l = 1.6;
wsp_modelu.y_suw_d_z = 1.3;
wsp_modelu.y_suw_d_w = 1.0;
wsp_modelu.y_suw_M = 0.7;

if nargin == 0,
   inicjowanie_okna(ogr,wsp_modelu);
elseif arg > 0, 
   inicjowanie_okna(ogr,wsp_modelu,param);
elseif arg == 0,
   ruch_myszki;
else
   zmien_parametry(arg);
end

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
function param = inicjowanie_okna(ogr,wsp,param)

% Ustawienie propozycji wartosci parametrow:
if nargin == 2, 
   param.M = 70;     % masa ciala (bez nog) [kg]
   param.l = 40;     % dlugosc kosci (rury) [cm]
   param.d_z = 3;    % srednica zewnetrzna kosci (rury) [cm]
   param.d_w = 80; % % srednica wewnetrzna kosci [w % srednicy zewnetrznej]
end

% Utworzenie okienka
set(gcf,'numbertitle','off','menubar','none')
clf

% suwaki:
hd_z = uicontrol(...
   'Style','slider', ...
   'Units','normalized', ...
   'Position',[.75 wsp.y_suw_d_z/2 .22 .06], ...
   'String','M', ...
   'Min',ogr.d_z_min,...
   'Max',ogr.d_z_max,...
   'Value',param.d_z,...
   'Callback','przysiad_gui(-2)');
hd_w = uicontrol(...
   'Style','slider', ...
   'Units','normalized', ...
   'Position',[.75 wsp.y_suw_d_w/2 .22 .06], ...
   'String','M', ...
   'Min',ogr.d_w_min,...
   'Max',ogr.d_w_max,...
   'Value',param.d_w,...
   'Callback','przysiad_gui(-3)');
hM = uicontrol(...
   'Style','slider', ...
   'Units','normalized', ...
   'Position',[.75 wsp.y_suw_M/2 .22 .06], ...
   'String','M', ...
   'Min',ogr.M_min,...
   'Max',ogr.M_max,...
   'Value',param.M,...
   'Callback','przysiad_gui(-4)');
hl = uicontrol(...
   'Style','slider', ...
   'Units','normalized', ...
   'Position',[.75 wsp.y_suw_l/2 .22 .06], ...
   'String','l', ...
   'Min',ogr.l_min,...
   'Max',ogr.l_max,...
   'Value',param.l,...
   'Callback','przysiad_gui(-1)');
uicontrol(...
   'style','pushbutton', ...
   'units','normalized', ...
   'position',[.75 .10 .22 .06], ...
   'string','Zamknij', ...
   'callback','close(gcf)');

axis([-1.5 0.7 -0.2 2.0]);
axis square,
set(gca,'XTick',[],'YTick',[]);
set(gca,'Position',[0.01, 0.11, 0.775, 0.815])
kolor_modelu = [0 0 1];
kolor_kosci = [1 0 0];
wys = 0.02*param.l;

% Opis suwakow:
text(0.91,wsp.y_suw_l+.29,'Dlugosc kosci l','FontSize',10);
h_txt_l = text(1.05,wsp.y_suw_l+.0,strcat(num2str(get(hl,'Value'),'%4.1f'),' cm'),'FontSize',10);
text(0.91,wsp.y_suw_d_z+.175,'Srednica zewnetrzna d','FontSize',10);
h_txt_d_z = text(1.05,wsp.y_suw_d_z-.11,strcat(num2str(get(hd_z,'Value'),'%4.1f'),' cm'),'FontSize',10);
text(0.91,wsp.y_suw_d_w+.07,'Srednica wewnetrzna','FontSize',10);
h_txt_d_w = text(1.06,wsp.y_suw_d_w-.20,strcat(num2str(get(hd_w,'Value'),'%4.1f'),'% d'),'FontSize',10);
text(0.91,wsp.y_suw_M-.04,'Masa ciala M','FontSize',10);
h_txt_M = text(1.05,wsp.y_suw_M-.31,strcat(num2str(get(hM,'Value'),'%4.1f'),' kg'),'FontSize',10);

dane.param = param;
dane.ogr = ogr;
dane.wsp = wsp;
dane.h = [hl, hd_z, hd_w, hM];
dane.h_txt = [h_txt_l, h_txt_d_z, h_txt_d_w, h_txt_M];
[r,h] = rysuj_model(wys,param,kolor_kosci,kolor_modelu,wsp);
dane.rys = r;  dane.h_sigma = h;
xlabel('Suwakami ustaw parametry i przesuwaj model w pionie','Fontweight','bold')
set(gcf,'name','Zmiany naprezen w kosci udowej w czasie przysiadu')
set(gcf,'tag','Pokaz przysiadu', ...
   'userdata',dane, ...
   'windowbuttondownfcn', ...
      'przysiad_gui(0); set(gcf,''windowbuttonmotionfcn'',''przysiad_gui(0)'')', ...
   'windowbuttonupfcn', ...
      'set(gcf,''windowbuttonmotionfcn'','''')')

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
function [rys, h_sigma] = rysuj_model(wys,param,kolor1,kolor2,wsp)
szer_podstawy = 0.5;
% rysunek podstawy:
line([wsp.stopa_x-szer_podstawy, wsp.stopa_x+szer_podstawy], [wsp.stopa_y, wsp.stopa_y]-0.01,'color','k','LineWidth',2);  % podstawa

% rysunek nogi, stopy i reki:
sq = sqrt((param.l/100)^2-wys^2/4);
x = wsp.stopa_x + [0, sq, 0];
y = [wsp.stopa_y, wys/2, wys];
rys.wysokosc1 = line(x,y,'Color',kolor2,'LineWidth',4,'Marker','o','MarkerSize',5);
rys.wysokosc2 = line(x(2:3),y(2:3),'Color',kolor1,'LineWidth',4);
line(wsp.stopa_x+[-0.2,0.06],[wsp.stopa_y,wsp.stopa_y],'Color',kolor2,'LineWidth',4);
x = wsp.stopa_x + [0, -sq*wsp.r/param.l];
y = 0.9*wsp.h+wys + [0, -wys/2*wsp.r/param.l];  %  wsp.r/param.l*sqrt(1-sq2/(param.l/100)^2)]; 
rys.reka = line(x,y,'Color',kolor2,'LineWidth',8);

% rysunek korpusu i glowy:
x = [wsp.stopa_x, wsp.stopa_x];
y = [wys, wys+wsp.h];
rys.korpus = line(x,y,'Color',kolor2,'LineWidth',30);
rys.glowa = line(wsp.stopa_x,wys+wsp.h+wsp.g,'Color',kolor2,'Marker','o','MarkerSize',30,'MarkerFaceColor',kolor2);

% wyresy slupkowe:
[sigma_p, sigma_o] = oblicz_naprezenia(param,wys);
rys.zginanie = line([wsp.zx, wsp.zx],wsp.zy+[0, sigma_p]*wsp.skala,'Color',[.87 .49 0],'LineWidth',15);
rys.sciskanie = line([wsp.sx, wsp.sx],wsp.sy+[0, sigma_o]*wsp.skala,'Color',[.17 .51 .34],'LineWidth',15);
text(wsp.sx-.05,wsp.sy-0.09,'\sigma_o=','FontSize',12);
text(wsp.zx-.05,wsp.zy-0.09,'\sigma_p=','FontSize',12);
h_sigma(1) = text(wsp.zx+.12,wsp.zy-0.09,strcat(num2str(sigma_p/1e6,'%4.2f'),'MPa'),'FontSize',10);
h_sigma(2) = text(wsp.sx+0.13,wsp.sy-0.09,strcat(num2str(sigma_o/1e6,'%4.2f'),'MPa'),'FontSize',10);

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
function ruch_myszki
dane = get(gcf,'Userdata');
pt = get(gca,'Currentpoint');
nowa_wys = pt(1,2);
if nowa_wys > 0.02*dane.param.l, nowa_wys = 0.02*dane.param.l; end
nowa_wys =max(nowa_wys, 0);
przesun_korpus(dane.rys,dane.param,dane.wsp,nowa_wys);
rysuj_wykresy(dane.rys,dane.param,dane.wsp,dane.h_sigma,nowa_wys);

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
function przesun_korpus(rys,param,wsp,y_nowy)
x = get(rys.wysokosc1,'xdata');
sq = sqrt((param.l/100)^2-y_nowy^2/4);
x(2) = wsp.stopa_x - sq;
y = get(rys.wysokosc1,'ydata');
y(2:3) = [y_nowy/2, y_nowy];
set(rys.wysokosc1,'xdata',x,'ydata',y);
x = get(rys.wysokosc2,'xdata');
x(1) = wsp.stopa_x - sq;
y = get(rys.wysokosc2,'ydata');
y = [y_nowy/2, y_nowy];
set(rys.wysokosc2,'xdata',x,'ydata',y);

x = wsp.stopa_x + [0, -sq*wsp.r/param.l];
y = 0.9*wsp.h+y_nowy + [0, -y_nowy/2*wsp.r/param.l];  %  wsp.r/param.l*sqrt(1-sq2/(param.l/100)^2)]; 
set(rys.reka,'xdata',x,'ydata',y);

y = [y_nowy, y_nowy+wsp.h];
set(rys.korpus,'ydata',y);
set(rys.glowa,'ydata',y_nowy+wsp.h+wsp.g);

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
function rysuj_wykresy(rys,param,wsp,h_sigma,y_nowy)
[s_p,s_o] = oblicz_naprezenia(param,y_nowy);
y = get(rys.zginanie,'ydata');
y(2) = s_p*wsp.skala;
set(rys.zginanie,'ydata',y);
set(h_sigma(1),'String',strcat(num2str(s_p/1e6,'%4.2f'),'MPa'));
y = get(rys.sciskanie,'ydata');
y(2) = s_o*wsp.skala;
set(rys.sciskanie,'ydata',y);
set(h_sigma(2),'String',strcat(num2str(s_o/1e6,'%4.2f'),'MPa'));

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
function [s_p,s_o] = oblicz_naprezenia(param,wys),
F = 9.81*param.M/2;  % Ciezar przypadajacy na jedna noge
Fo = F*wys/(2*param.l/100);
Fp = sqrt(F^2-Fo^2);
S = pi*param.d_z^2/4e4*(1-param.d_w^2/1e4);
s_p = Fp*param.l/(S*param.d_z);
s_o = Fo/S;

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
function zmien_parametry(arg),
dane = get(gcf,'Userdata');
param = dane.param;
h = dane.h;
ht = dane.h_txt;
wsp = dane.wsp;
    switch arg,
    case -1,
        param.l = get(h(-arg),'Value');
        set(ht(-arg),'String',strcat(num2str(param.l,'%4.1f'),' cm'));
    case -2,
        param.d_z = get(h(-arg),'Value');
        set(ht(-arg),'String',strcat(num2str(param.d_z,'%4.1f'),' cm'));
    case -3,
        param.d_w = get(h(-arg),'Value');
        set(ht(-arg),'String',strcat(num2str(param.d_w,'%4.1f'),' % d'));
    case -4,
        param.M = get(h(-arg),'Value');
        set(ht(-arg),'String',strcat(num2str(param.M,'%4.1f'),' kg'));
    end
dane.param = param;
set(gcf,'Userdata',dane);
