% nowotwor_1_gui.m 
%
% AGH Akademia Grniczo-Hutnicza w Krakowie
% Laboratorium Biocybernetyki
%
% Wprowadzenie do modelowania cybernetycznego 
% systemw biologicznych oraz ich symulacji w rodowisku MATLAB
%---------------------------------------------------------------------
% Symulacja proliferacji komrek nowotworowych

function nowotwor_1_gui(arg)
wsp_modelu.y_gamma = 0.8;
wsp_modelu.y_P0 = 0.65;
wsp_modelu.y_czas = 0.5;
% gamma = wsp_modelu.y_gamma;
if nargin == 0,
   inicjowanie_okna(wsp_modelu);
elseif arg > 0, 
   inicjowanie_okna(wsp_modelu,param);
elseif arg == 0,
   symulacja();
else
   zmien_parametry(arg);
end

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
function param = inicjowanie_okna(wsp,param)
global param
% Ustawienie propozycji wartosci parametrow:
if nargin == 1, 
   param.gamma = 0.01;     % wspolczynnik proliferacji [1/h]
   param.P0    = 2e8;      % poczatkowa liczba komorek
   param.czas  = 120;      % czas symulacji [h]
   dane.param = param;
   set(gcf,'Userdata',dane);
end

% Utworzenie okienka
set(gcf,'numbertitle','off','menubar','none',...
        'Name','Symulacja proliferacji komorek nowotworowych');
clf
set(gca,'Position',[0.1, 0.11, 0.6, 0.815])

% Pola edycji wartosci parametrow i przycisk SYMULACJA:
wsp_x = 0.8;   szer = 0.15;   wys = 0.06;
h_gamma = uicontrol(...
   'Style','edit', ...
   'Units','normalized', ...
   'BackgroundColor','w',...
   'ForegroundColor','k',...
   'FontSize',12,...
   'Position',[wsp_x wsp.y_gamma szer wys], ...
   'String',num2str(param.gamma), ...
   'Value',param.gamma,...
   'Callback','nowotwor_1_gui(-1)');
h_P0 = uicontrol(...
   'Style','edit', ...
   'Units','normalized', ...
   'BackgroundColor','w',...
   'ForegroundColor','k',...
   'FontSize',12,...
   'Position',[wsp_x wsp.y_P0 szer wys], ...
   'String',num2str(param.P0,'%5.1e'), ...
   'Value',param.P0,...
   'Callback','nowotwor_1_gui(-2)');
h_czas = uicontrol(...
   'Style','edit', ...
   'Units','normalized', ...
   'BackgroundColor','w',...
   'ForegroundColor','k',...
   'FontSize',12,...
   'Position',[wsp_x wsp.y_czas szer wys], ...
   'String',num2str(param.czas), ...
   'Value',param.czas,...
   'Callback','nowotwor_1_gui(-3)');
uicontrol(...
   'style','pushbutton', ...
   'units','normalized', ...
   'position',[wsp_x .10 szer wys], ...
   'string','SYMULACJA', ...
   'callback','nowotwor_1_gui(0)');

opis_pol();
dane.param = param;
dane.wsp = wsp;
dane.h = [h_gamma, h_P0, h_czas];
symulacja();
set(gcf,'tag','Symulacja wzrostu guza','userdata',dane); 

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
function symulacja()
global gamma;  
dane = get(gcf,'Userdata');
param = dane.param;
gamma = param.gamma;
[t,P] = ode45(@rownanie_proliferacji,[0,param.czas],param.P0);

% Wyprowadzenie wynikow w formie graficznej:
cla;
plot(t,P,'r');
set(gca,'Position',[0.1, 0.11, 0.6, 0.815])
grid;
opis_pol();
xlabel('Czas {\itt} [h]');
ylabel('Liczba komorek nowotworowych {\itP(t)}');

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Funkcja obliczajaca prawa strone rown.rozniczkowego
function dP_dt = rownanie_proliferacji(t,P),
global gamma;
dP_dt = gamma*P;         % rownanie rozniczkowe (26)

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Funkcja opisujaca pola edycji
function opis_pol(),
% Opis pol edycji:
ha = get(gca);
x=ha.XLim; y=ha.YLim; 
% y=get(ha,'YLim');
wx=125/120*x(2); 
wy=62/70*(y(2)-y(1))+y(1); 
h=text(wx,wy,'{\it\gamma} [1/h]','FontSize',12);
wx=128/120*x(2); 
wy=49/70*(y(2)-y(1))+y(1); 
h=text(wx,wy,'{\itP}(0)','FontSize',12);
wy=36/70*(y(2)-y(1))+y(1); 
h=text(wx,wy,'{\itT} [h]','FontSize',12);

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
function zmien_parametry(arg),
dane = get(gcf,'Userdata');
param = dane.param;
h = dane.h;
wsp = dane.wsp;
    switch arg,
    case -1,
        param.gamma = str2num(get(h(-arg),'String'));
        set(h(-arg),'Value',param.gamma);
    case -2,
        param.P0 = str2num(get(h(-arg),'String'));
        set(h(-arg),'Value',param.P0);
    case -3,
        param.czas = str2num(get(h(-arg),'String'));
        set(h(-arg),'Value',param.czas);
    end
dane.param = param;
set(gcf,'Userdata',dane);
