% nowotwor_2_gui.m 
%
% AGH Akademia Grniczo-Hutnicza w Krakowie
% Laboratorium Biocybernetyki
%
% Wprowadzenie do modelowania cybernetycznego 
% systemw biologicznych oraz ich symulacji w rodowisku MATLAB
%---------------------------------------------------------------------
% Symulacja proliferacji i uspokajania komrek nowotworowych

function nowotwor_2_gui(arg)
wsp_modelu.y_alfa = 0.85;
wsp_modelu.y_beta = 0.75;
wsp_modelu.y_gamma = 0.65;
wsp_modelu.y_P0 = 0.55;
wsp_modelu.y_Q0 = 0.45;
wsp_modelu.y_czas = 0.35;
% gamma = wsp_modelu.y_gamma;
if nargin == 0,
   inicjowanie_okna(wsp_modelu);
elseif arg > 0, 
   inicjowanie_okna(wsp_modelu,param);
elseif arg == 0,
   symulacja();
else
   zmien_parametry(arg);
end

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
function param = inicjowanie_okna(wsp,param)
global param
% Ustawienie propozycji wartosci parametrow:
if nargin == 1, 
   param.alfa = 0.02;      % wspolczynnik uspakajania [1/h]
   param.beta = 0.004;     % wspolczynnik powrotu do mnozenia [1/h]
   param.gamma = 0.01;     % wspolczynnik proliferacji [1/h]
   param.P0    = 2e8;      % poczatkowa liczba komorek proliferujacych
   param.Q0    = 8e8;      % poczatkowa liczba komorek uspokojonych
   param.czas  = 120;      % czas symulacji [h]
   dane.param = param;
   set(gcf,'Userdata',dane);
end

% Utworzenie okienka
set(gcf,'numbertitle','off','menubar','none',...
        'Name','Symulacja proliferacji i uspakajania komorek nowotworowych');
clf
set(gca,'Position',[0.1, 0.11, 0.6, 0.815])

% Pola edycji wartosci parametrow i przycisk SYMULACJA:
wsp_x = 0.8;   szer = 0.15;   wys = 0.06;
h_alfa = uicontrol(...
   'Style','edit', ...
   'Units','normalized', ...
   'BackgroundColor','w',...
   'ForegroundColor','k',...
   'FontSize',12,...
   'Position',[wsp_x wsp.y_alfa szer wys], ...
   'String',num2str(param.alfa), ...
   'Value',param.alfa,...
   'Callback','nowotwor_2_gui(-1)');
h_beta = uicontrol(...
   'Style','edit', ...
   'Units','normalized', ...
   'BackgroundColor','w',...
   'ForegroundColor','k',...
   'FontSize',12,...
   'Position',[wsp_x wsp.y_beta szer wys], ...
   'String',num2str(param.beta), ...
   'Value',param.beta,...
   'Callback','nowotwor_2_gui(-2)');
h_gamma = uicontrol(...
   'Style','edit', ...
   'Units','normalized', ...
   'BackgroundColor','w',...
   'ForegroundColor','k',...
   'FontSize',12,...
   'Position',[wsp_x wsp.y_gamma szer wys], ...
   'String',num2str(param.gamma), ...
   'Value',param.gamma,...
   'Callback','nowotwor_2_gui(-3)');
h_P0 = uicontrol(...
   'Style','edit', ...
   'Units','normalized', ...
   'BackgroundColor','w',...
   'ForegroundColor','k',...
   'FontSize',12,...
   'Position',[wsp_x wsp.y_P0 szer wys], ...
   'String',num2str(param.P0,'%5.1e'), ...
   'Value',param.P0,...
   'Callback','nowotwor_2_gui(-4)');
h_Q0 = uicontrol(...
   'Style','edit', ...
   'Units','normalized', ...
   'BackgroundColor','w',...
   'ForegroundColor','k',...
   'FontSize',12,...
   'Position',[wsp_x wsp.y_Q0 szer wys], ...
   'String',num2str(param.Q0,'%5.1e'), ...
   'Value',param.Q0,...
   'Callback','nowotwor_2_gui(-5)');
h_czas = uicontrol(...
   'Style','edit', ...
   'Units','normalized', ...
   'BackgroundColor','w',...
   'ForegroundColor','k',...
   'FontSize',12,...
   'Position',[wsp_x wsp.y_czas szer wys], ...
   'String',num2str(param.czas), ...
   'Value',param.czas,...
   'Callback','nowotwor_2_gui(-6)');
uicontrol(...
   'style','pushbutton', ...
   'units','normalized', ...
   'position',[wsp_x .10 szer wys], ...
   'string','SYMULACJA', ...
   'callback','nowotwor_2_gui(0)');

opis_pol();
dane.param = param;
dane.wsp = wsp;
dane.h = [h_alfa, h_beta, h_gamma, h_P0, h_Q0, h_czas];
symulacja();
set(gcf,'userdata',dane); 

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
function symulacja()
global alfa beta gamma;  
dane = get(gcf,'Userdata');
param = dane.param;
alfa = param.alfa;
beta = param.beta;
gamma = param.gamma;
[t,PQ] = ode45(@rownanie_proliferacji_2,[0,param.czas],[param.P0; param.Q0]);

% Wyprowadzenie wynikow w formie graficznej:
cla;
plot(t,PQ(:,1),'r',t,PQ(:,2),'b');
set(gca,'Position',[0.1, 0.11, 0.6, 0.815])
grid;
opis_pol();
xlabel('Czas {\itt} [h]');
ylabel('Liczba komorek nowotworowych {\itP(t)} i {\itQ(t)}');

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Funkcja obliczajaca prawa strone rown.rozniczkowego
function dPQ_dt = rownanie_proliferacji_2(t,PQ),
global alfa beta gamma;
P = PQ(1);  Q = PQ(2);
dP_dt = (gamma-alfa)*P + beta*Q;         % rownanie rozniczkowe (29)
dQ_dt = alfa*P - beta*Q;                 % rownanie rozniczkowe (30)
dPQ_dt = [dP_dt; dQ_dt];

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Funkcja opisujaca pola edycji
function opis_pol(),
% Opis pol edycji:
ha = get(gca);
x=ha.XLim; y=ha.YLim; 
wx=123/120*x(2); 
wy=66/70*(y(2)-y(1))+y(1); 
h=text(wx,wy,'{\it\alpha} [1/h]','FontSize',12);
wx=123/120*x(2); 
wy=57.5/70*(y(2)-y(1))+y(1); 
h=text(wx,wy,'{\it\beta} [1/h]','FontSize',12);
wx=124/120*x(2); 
wy=49/70*(y(2)-y(1))+y(1); 
h=text(wx,wy,'{\it\gamma} [1/h]','FontSize',12);
wx=128/120*x(2); 
wy=40.5/70*(y(2)-y(1))+y(1); 
h=text(wx,wy,'{\itP}(0)','FontSize',12,'Color','r');
wx=128/120*x(2); 
wy=32/70*(y(2)-y(1))+y(1); 
h=text(wx,wy,'{\itQ}(0)','FontSize',12,'Color','b');
wy=23.5/70*(y(2)-y(1))+y(1); 
h=text(wx,wy,'{\itT} [h]','FontSize',12);
legend('P','Q','Location','Best');
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
function zmien_parametry(arg),
dane = get(gcf,'Userdata');
param = dane.param;
h = dane.h;
wsp = dane.wsp;
    switch arg,
    case -1,
        param.alfa = str2num(get(h(-arg),'String'));
        set(h(-arg),'Value',param.alfa);
    case -2,
        param.beta = str2num(get(h(-arg),'String'));
        set(h(-arg),'Value',param.beta);
    case -3,
        param.gamma = str2num(get(h(-arg),'String'));
        set(h(-arg),'Value',param.gamma);
    case -4,
        param.P0 = str2num(get(h(-arg),'String'));
        set(h(-arg),'Value',param.P0);
    case -5,
        param.Q0 = str2num(get(h(-arg),'String'));
        set(h(-arg),'Value',param.Q0);
    case -6,
        param.czas = str2num(get(h(-arg),'String'));
        set(h(-arg),'Value',param.czas);
    end
dane.param = param;
set(gcf,'Userdata',dane);
