% nowotwor_3_gui.m 
%
% AGH Akademia Grniczo-Hutnicza w Krakowie
% Laboratorium Biocybernetyki
%
% Wprowadzenie do modelowania cybernetycznego 
% systemw biologicznych oraz ich symulacji w rodowisku MATLAB
%---------------------------------------------------------------------
% Symulacja oddzialywania leku na rozwj komrek nowotworowych
% (z moliwocia zadawania okresw podawania leku)
function nowotwor_3_gui(arg)
wsp_modelu.y_alfa = 0.85;
wsp_modelu.y_beta = 0.75;
wsp_modelu.y_gamma = 0.65;
wsp_modelu.y_delta = 0.55;
wsp_modelu.y_P0 = 0.45;
wsp_modelu.y_Q0 = 0.35;
wsp_modelu.y_xmax = 0.25;
wsp_modelu.y_czasy = 0.15;
if nargin == 0,
   inicjowanie_okna(wsp_modelu);
elseif arg > 0, 
   inicjowanie_okna(wsp_modelu,param);
elseif arg == 0,
   symulacja();
else
   zmien_parametry(arg);
end

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
function param = inicjowanie_okna(wsp,param)
global param
% Ustawienie propozycji wartosci parametrow:
if nargin == 1, 
   param.alfa = 0.02;      % wspolczynnik uspakajania [1/h]
   param.beta = 0.004;     % wspolczynnik powrotu do mnozenia [1/h]
   param.gamma = 0.01;     % wspolczynnik proliferacji [1/h]
   param.delta = 0.66;     % wspolczynnik oddzialywania leku
   param.P0    = 2e8;      % poczatkowa liczba komorek proliferujacych
   param.Q0    = 8e8;      % poczatkowa liczba komorek uspokojonych
   param.xmax  = 0.15;     % amplituda dawki 
   param.czasy = [2 7 9 14]*24; % czas wlaczenia/wylaczenia dozowania [h]
   dane.param = param;
   set(gcf,'Userdata',dane);
end

% Utworzenie okienka
set(gcf,'numbertitle','off','menubar','none',...
        'Name','Symulacja przebiegu leczenia guza nowotworowego');
clf
set(gca,'Position',[0.1, 0.30, 0.6, 0.635])

% Pola edycji wartosci parametrow i przycisk SYMULACJA:
wsp_x = 0.8;   szer = 0.15;   wys = 0.06;
h_alfa = uicontrol(...
   'Style','edit', ...
   'Units','normalized', ...
   'BackgroundColor','w',...
   'ForegroundColor','k',...
   'FontSize',12,...
   'Position',[wsp_x wsp.y_alfa szer wys], ...
   'String',num2str(param.alfa), ...
   'Value',param.alfa,...
   'Callback','nowotwor_3_gui(-1)');
h_beta = uicontrol(...
   'Style','edit', ...
   'Units','normalized', ...
   'BackgroundColor','w',...
   'ForegroundColor','k',...
   'FontSize',12,...
   'Position',[wsp_x wsp.y_beta szer wys], ...
   'String',num2str(param.beta), ...
   'Value',param.beta,...
   'Callback','nowotwor_3_gui(-2)');
h_gamma = uicontrol(...
   'Style','edit', ...
   'Units','normalized', ...
   'BackgroundColor','w',...
   'ForegroundColor','k',...
   'FontSize',12,...
   'Position',[wsp_x wsp.y_gamma szer wys], ...
   'String',num2str(param.gamma), ...
   'Value',param.gamma,...
   'Callback','nowotwor_3_gui(-3)');
h_delta = uicontrol(...
   'Style','edit', ...
   'Units','normalized', ...
   'BackgroundColor','w',...
   'ForegroundColor','k',...
   'FontSize',12,...
   'Position',[wsp_x wsp.y_delta szer wys], ...
   'String',num2str(param.delta), ...
   'Value',param.delta,...
   'Callback','nowotwor_3_gui(-4)');
h_P0 = uicontrol(...
   'Style','edit', ...
   'Units','normalized', ...
   'BackgroundColor','w',...
   'ForegroundColor','k',...
   'FontSize',12,...
   'Position',[wsp_x wsp.y_P0 szer wys], ...
   'String',num2str(param.P0,'%5.1e'), ...
   'Value',param.P0,...
   'Callback','nowotwor_3_gui(-5)');
h_Q0 = uicontrol(...
   'Style','edit', ...
   'Units','normalized', ...
   'BackgroundColor','w',...
   'ForegroundColor','k',...
   'FontSize',12,...
   'Position',[wsp_x wsp.y_Q0 szer wys], ...
   'String',num2str(param.Q0,'%5.1e'), ...
   'Value',param.Q0,...
   'Callback','nowotwor_3_gui(-6)');
h_xmax = uicontrol(...
   'Style','edit', ...
   'Units','normalized', ...
   'BackgroundColor','w',...
   'ForegroundColor','k',...
   'FontSize',12,...
   'Position',[wsp_x wsp.y_xmax szer wys], ...
   'String',num2str(param.xmax), ...
   'Value',param.xmax,...
   'Callback','nowotwor_3_gui(-7)');
h_czasy = uicontrol(...
   'Style','edit', ...
   'Units','normalized', ...
   'BackgroundColor','w',...
   'ForegroundColor','k',...
   'FontSize',10,...
   'Position',[wsp_x-0.03 wsp.y_czasy szer+0.08 wys], ...
   'String',num2str(param.czasy), ...
   'Value',param.czasy,...
   'Callback','nowotwor_3_gui(-8)');
uicontrol(...
   'style','pushbutton', ...
   'units','normalized', ...
   'position',[wsp_x .05 szer wys], ...
   'string','SYMULACJA', ...
   'callback','nowotwor_3_gui(0)');

opis_pol();
dane.param = param;
dane.wsp = wsp;
dane.h = [h_alfa, h_beta, h_gamma, h_delta, h_P0, h_Q0, h_xmax, h_czasy];
symulacja();
set(gcf,'userdata',dane); 

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
function symulacja()
global alfa beta gamma delta czasy xmax;  
dane = get(gcf,'Userdata');
param = dane.param;
alfa = param.alfa;
beta = param.beta;
gamma = param.gamma;
delta = param.delta;
xmax = param.xmax;
czasy = param.czasy;
T = czasy(end);
opcje=odeset('RelTol',1e-6);
[t,PQ] = ode23(@rownanie_proliferacji_3,[0,T],[param.P0; param.Q0],opcje);

% Wyprowadzenie wynikow w formie graficznej:
cla;
subplot(2,1,1),    % Wykres liczby komorek
plot(t,PQ(:,1),'r',t,PQ(:,2),'b'); ha1=gca;
legend('P','Q','Location','West');
% set(gca,'Position',[0.1, 0.11, 0.6, 0.815])
set(gca,'Position',[0.1, 0.5, 0.6, 0.635])
grid;
opis_pol();
ylabel('Liczba komorek nowotworowych {\itP(t)} i {\itQ(t)}');
subplot(2,1,2),  % Wykres dozowania
n=length(czasy);
ti=zeros(1,2*n);
ti(2:2:2*n)=czasy; ti(3:2:2*n)=czasy(1:end-1);
xi=zeros(1,2*n);
x=0;
for i=1:2:2*n, 
    xi(i)=x; xi(i+1)=x;
    if x==0, x=xmax;
    else x=0;
    end
end
plot(ti,xi,'g'); ha2=gca;
set(gca,'Position',[0.1, 0.11, 0.6, 0.15])
xlabel('Czas {\itt} [h]');
ylabel('{\itx(t)}');
set(ha1,'Position',[0.1, 0.3, 0.6, 0.635])

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Funkcja obliczajaca prawa strone rown.rozniczkowego
function dPQ_dt = rownanie_proliferacji_3(t,PQ),
global alfa beta gamma delta;
P = PQ(1);  Q = PQ(2);
x = dozowanie_leku(t);
dP_dt = (gamma-alfa-delta*x)*P + beta*Q; % rownanie rozniczkowe (29)
dQ_dt = alfa*P - beta*Q;                 % rownanie rozniczkowe (30)
dPQ_dt = [dP_dt; dQ_dt];

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%% 
% Funkcja wyznaczajaca wielkosc dawki leku w chwili t
function x = dozowanie_leku(t),
global xmax czasy;
% Dawka odpowiadajaca maksymalnemu stezeniu=2[ng/ml]:
% dawka_max = 0.15;
n=length(czasy);
x = 0;
for i=1:n,
    if t<czasy(i), break;  end,
    if x==0, x=xmax;
    else x=0;
    end,
end

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Funkcja opisujaca pola edycji
function opis_pol(),
% Opis pol edycji:
ha = get(gca);
x=ha.XLim; y=ha.YLim; 
wx=123/120*x(2); 
wy=64/70*(y(2)-y(1))+y(1); 
h=text(wx,wy,'{\it\alpha} [1/h]','FontSize',12);
wx=123/120*x(2); 
wy=53/70*(y(2)-y(1))+y(1); 
h=text(wx,wy,'{\it\beta} [1/h]','FontSize',12);
wx=124/120*x(2); 
wy=42/70*(y(2)-y(1))+y(1); 
h=text(wx,wy,'{\it\gamma} [1/h]','FontSize',12);
wx=124/120*x(2); 
wy=31/70*(y(2)-y(1))+y(1); 
h=text(wx,wy,'{\it\delta} [1/h]','FontSize',12);
wx=128/120*x(2); 
wy=20/70*(y(2)-y(1))+y(1); 
h=text(wx,wy,'{\itP}(0)','FontSize',12,'Color','r');
wx=128/120*x(2); 
wy=9/70*(y(2)-y(1))+y(1); 
h=text(wx,wy,'{\itQ}(0)','FontSize',12,'Color','b');
wx=127/120*x(2); 
wy=-2/70*(y(2)-y(1))+y(1); 
h=text(wx,wy,'{\itx_{max}}','FontSize',12);
wx=122/120*x(2); 
wy=-14/70*(y(2)-y(1))+y(1); 
h=text(wx,wy,'{\itt_i} [h]','FontSize',12);

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
function zmien_parametry(arg),
dane = get(gcf,'Userdata');
param = dane.param;
h = dane.h;
wsp = dane.wsp;
    switch arg,
    case -1,
        param.alfa = str2num(get(h(-arg),'String'));
        set(h(-arg),'Value',param.alfa);
    case -2,
        param.beta = str2num(get(h(-arg),'String'));
        set(h(-arg),'Value',param.beta);
    case -3,
        param.gamma = str2num(get(h(-arg),'String'));
        set(h(-arg),'Value',param.gamma);
    case -4,
        param.delta = str2num(get(h(-arg),'String'));
        set(h(-arg),'Value',param.delta);
    case -5,
        param.P0 = str2num(get(h(-arg),'String'));
        set(h(-arg),'Value',param.P0);
    case -6,
        param.Q0 = str2num(get(h(-arg),'String'));
        set(h(-arg),'Value',param.Q0);
    case -7,
        param.xmax = str2num(get(h(-arg),'String'));
        set(h(-arg),'Value',param.xmax);
    case -8,
        param.czasy = str2num(get(h(-arg),'String'));
        set(h(-arg),'Value',param.czasy);
    end
dane.param = param;
set(gcf,'Userdata',dane);
