% nowotwor_4_gui.m 
%
% AGH Akademia Grniczo-Hutnicza w Krakowie
% Laboratorium Biocybernetyki
%
% Wprowadzenie do modelowania cybernetycznego 
% systemw biologicznych oraz ich symulacji w rodowisku MATLAB
%---------------------------------------------------------------------
% Symulacja oddzialywania leku na rozwoj komorek nowotworowych
% oraz skutku ubocznego - oddziaywania leku na ukad krwiotwrczy
% W programie wykorzystano model opublikowany na stronie
% http://www.math.unl.edu/%7Ebdeng1/Teaching/math943/Student%20Lectures/Molly/BlastingNeuroblastoma.pdf

function nowotwor_4_gui(arg)
gr_y0=0.05; gr_dy=0.075;
wsp_modelu.y_alfa = gr_y0+11*gr_dy;
wsp_modelu.y_beta = gr_y0+10*gr_dy;
wsp_modelu.y_gamma = gr_y0+9*gr_dy;
wsp_modelu.y_delta = gr_y0+8*gr_dy;
wsp_modelu.y_P0 = gr_y0+7*gr_dy;
wsp_modelu.y_Q0 = gr_y0+6*gr_dy;
wsp_modelu.y_ke = gr_y0+5*gr_dy;
wsp_modelu.y_kcp = gr_y0+4*gr_dy;
wsp_modelu.y_kpc = gr_y0+3*gr_dy;
wsp_modelu.y_xmax = gr_y0+2*gr_dy;
wsp_modelu.y_czasy = gr_y0+gr_dy;
wsp_modelu.y_kin = gr_y0+11*gr_dy;
wsp_modelu.y_Km = gr_y0+10*gr_dy;
wsp_modelu.y_IC50 = gr_y0+9*gr_dy;
wsp_modelu.y_kbp = gr_y0+8*gr_dy;
wsp_modelu.y_kout = gr_y0+7*gr_dy;
wsp_modelu.y_Np0 = gr_y0+6*gr_dy;
wsp_modelu.y_Nd10 = gr_y0+5*gr_dy;
wsp_modelu.y_Nd20 = gr_y0+4*gr_dy;
wsp_modelu.y_Nd30 = gr_y0+3*gr_dy;
wsp_modelu.y_Ncirc0 = gr_y0+2*gr_dy;
wsp_modelu.gr_y0=gr_y0;
wsp_modelu.gr_dy=gr_dy;
if nargin == 0,
   inicjowanie_okna(wsp_modelu);
elseif arg > 0, 
   inicjowanie_okna(wsp_modelu,param);
elseif arg == 0,
   symulacja();
elseif arg ==-100,
   pomocnik();
else
   zmien_parametry(arg);
end

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
function param = inicjowanie_okna(wsp,param)
global param
% Ustawienie propozycji wartosci parametrow:
if nargin == 1, 
   param.alfa = 0.02;      % wspolczynnik uspakajania [1/h]
   param.beta = 0.0042;    % wspolczynnik powrotu do mnozenia [1/h]
   param.gamma = 0.011;    % wspolczynnik proliferacji [1/h]
   param.delta = 0.66;     % wspolczynnik oddzialywania leku
% wspczynniki transferu leku:
   param.ke    = 0.83;
   param.kcp   = 0.26;
   param.kpc   = 0.27;
% parametry modelu ukadu krwiotwrczego:
   param.kin   = 0.09;
   param.Km    = 3100;
   param.IC50  = 1.45;
   param.kbp   = 0.07;
   param.kout   = 0.1;
% warunki pocztkowe:   
   param.P0    = 2e8;      % poczatkowa liczba komorek proliferujacych
   param.Q0    = 8e8;      % poczatkowa liczba komorek uspokojonych
   param.Np0   =2000;  
   param.Nd10  =2300;   
   param.Nd20  =2400;
   param.Nd30  =2100;
   param.Ncirc0=1500;
   param.yc0   =   0; 
   param.yp0   =   0;

   param.xmax  = 0.15;     % amplituda dawki 
   param.czasy = [2 7 9 14 14.5]*24; % czas wlaczenia/wylaczenia dozowania [h]
   param.V     =0.032;
   dane.param = param;
   set(gcf,'UserData',dane);
end

% Utworzenie okienka
set(gcf,'numbertitle','off',...%'menubar','none',...
        'Name','Symulacja leczenia guza i wplywu na uklad krwiotworczy');
set(gcf,'Position',[100, 50, 800, 600])
clf
set(gca,'Position',[0.06, 0.30, 0.5, 0.635])

% Pola edycji wartosci parametrow i przyciski SYMULACJA i POMOCNIK:
wsp_x1 = 0.67;   szer = 0.12;   wys = 0.04;
h_alfa = uicontrol(...
   'Style','edit', ...
   'Units','normalized', ...
   'BackgroundColor','w',...
   'ForegroundColor','k',...
   'FontSize',12,...
   'Position',[wsp_x1 wsp.y_alfa szer wys], ...
   'String',num2str(param.alfa), ...
   'Value',param.alfa,...
   'Callback','nowotwor_4_gui(-1)');
h_beta = uicontrol(...
   'Style','edit', ...
   'Units','normalized', ...
   'BackgroundColor','w',...
   'ForegroundColor','k',...
   'FontSize',12,...
   'Position',[wsp_x1 wsp.y_beta szer wys], ...
   'String',num2str(param.beta), ...
   'Value',param.beta,...
   'Callback','nowotwor_4_gui(-2)');
h_gamma = uicontrol(...
   'Style','edit', ...
   'Units','normalized', ...
   'BackgroundColor','w',...
   'ForegroundColor','k',...
   'FontSize',12,...
   'Position',[wsp_x1 wsp.y_gamma szer wys], ...
   'String',num2str(param.gamma), ...
   'Value',param.gamma,...
   'Callback','nowotwor_4_gui(-3)');
h_delta = uicontrol(...
   'Style','edit', ...
   'Units','normalized', ...
   'BackgroundColor','w',...
   'ForegroundColor','k',...
   'FontSize',12,...
   'Position',[wsp_x1 wsp.y_delta szer wys], ...
   'String',num2str(param.delta), ...
   'Value',param.delta,...
   'Callback','nowotwor_4_gui(-4)');
h_P0 = uicontrol(...
   'Style','edit', ...
   'Units','normalized', ...
   'BackgroundColor','w',...
   'ForegroundColor','k',...
   'FontSize',12,...
   'Position',[wsp_x1 wsp.y_P0 szer wys], ...
   'String',num2str(param.P0,'%5.1e'), ...
   'Value',param.P0,...
   'Callback','nowotwor_4_gui(-5)');
h_Q0 = uicontrol(...
   'Style','edit', ...
   'Units','normalized', ...
   'BackgroundColor','w',...
   'ForegroundColor','k',...
   'FontSize',12,...
   'Position',[wsp_x1 wsp.y_Q0 szer wys], ...
   'String',num2str(param.Q0,'%5.1e'), ...
   'Value',param.Q0,...
   'Callback','nowotwor_4_gui(-6)');
h_ke = uicontrol(...
   'Style','edit', ...
   'Units','normalized', ...
   'BackgroundColor','w',...
   'ForegroundColor','k',...
   'FontSize',12,...
   'Position',[wsp_x1 wsp.y_ke szer wys], ...
   'String',num2str(param.ke), ...
   'Value',param.ke,...
   'Callback','nowotwor_4_gui(-7)');
h_kcp = uicontrol(...
   'Style','edit', ...
   'Units','normalized', ...
   'BackgroundColor','w',...
   'ForegroundColor','k',...
   'FontSize',12,...
   'Position',[wsp_x1 wsp.y_kcp szer wys], ...
   'String',num2str(param.kcp), ...
   'Value',param.kcp,...
   'Callback','nowotwor_4_gui(-8)');
h_kpc = uicontrol(...
   'Style','edit', ...
   'Units','normalized', ...
   'BackgroundColor','w',...
   'ForegroundColor','k',...
   'FontSize',12,...
   'Position',[wsp_x1 wsp.y_kpc szer wys], ...
   'String',num2str(param.kpc'), ...
   'Value',param.kpc,...
   'Callback','nowotwor_4_gui(-9)');
h_xmax = uicontrol(...
   'Style','edit', ...
   'Units','normalized', ...
   'BackgroundColor','w',...
   'ForegroundColor','k',...
   'FontSize',12,...
   'Position',[wsp_x1 wsp.y_xmax szer wys], ...
   'String',num2str(param.xmax), ...
   'Value',param.xmax,...
   'Callback','nowotwor_4_gui(-10)');

wsp_x2 = 0.87;   szer = 0.12;   wys = 0.04;
h_kin = uicontrol(...
   'Style','edit', ...
   'Units','normalized', ...
   'BackgroundColor','w',...
   'ForegroundColor','k',...
   'FontSize',12,...
   'Position',[wsp_x2 wsp.y_kin szer wys], ...
   'String',num2str(param.kin), ...
   'Value',param.kin,...
   'Callback','nowotwor_4_gui(-11)');
h_Km = uicontrol(...
   'Style','edit', ...
   'Units','normalized', ...
   'BackgroundColor','w',...
   'ForegroundColor','k',...
   'FontSize',12,...
   'Position',[wsp_x2 wsp.y_Km szer wys], ...
   'String',num2str(param.Km), ...
   'Value',param.Km,...
   'Callback','nowotwor_4_gui(-12)');
h_IC50 = uicontrol(...
   'Style','edit', ...
   'Units','normalized', ...
   'BackgroundColor','w',...
   'ForegroundColor','k',...
   'FontSize',12,...
   'Position',[wsp_x2 wsp.y_IC50 szer wys], ...
   'String',num2str(param.IC50), ...
   'Value',param.IC50,...
   'Callback','nowotwor_4_gui(-13)');
h_kbp = uicontrol(...
   'Style','edit', ...
   'Units','normalized', ...
   'BackgroundColor','w',...
   'ForegroundColor','k',...
   'FontSize',12,...
   'Position',[wsp_x2 wsp.y_kbp szer wys], ...
   'String',num2str(param.kbp), ...
   'Value',param.kbp,...
   'Callback','nowotwor_4_gui(-14)');
h_kout = uicontrol(...
   'Style','edit', ...
   'Units','normalized', ...
   'BackgroundColor','w',...
   'ForegroundColor','k',...
   'FontSize',12,...
   'Position',[wsp_x2 wsp.y_kout szer wys], ...
   'String',param.kout, ...
   'Value',param.kout,...
   'Callback','nowotwor_4_gui(-15)');
h_Np0 = uicontrol(...
   'Style','edit', ...
   'Units','normalized', ...
   'BackgroundColor','w',...
   'ForegroundColor','k',...
   'FontSize',12,...
   'Position',[wsp_x2 wsp.y_Np0 szer wys], ...
   'String',param.Np0, ...
   'Value',param.Np0,...
   'Callback','nowotwor_4_gui(-16)');
h_Nd10 = uicontrol(...
   'Style','edit', ...
   'Units','normalized', ...
   'BackgroundColor','w',...
   'ForegroundColor','k',...
   'FontSize',12,...
   'Position',[wsp_x2 wsp.y_Nd10 szer wys], ...
   'String',param.Nd10, ...
   'Value',param.Nd10,...
   'Callback','nowotwor_4_gui(-17)');
h_Nd20 = uicontrol(...
   'Style','edit', ...
   'Units','normalized', ...
   'BackgroundColor','w',...
   'ForegroundColor','k',...
   'FontSize',12,...
   'Position',[wsp_x2 wsp.y_Nd20 szer wys], ...
   'String',param.Nd20, ...
   'Value',param.Nd20,...
   'Callback','nowotwor_4_gui(-18)');
h_Nd30 = uicontrol(...
   'Style','edit', ...
   'Units','normalized', ...
   'BackgroundColor','w',...
   'ForegroundColor','k',...
   'FontSize',12,...
   'Position',[wsp_x2 wsp.y_Nd30 szer wys], ...
   'String',param.Nd30, ...
   'Value',param.Nd30,...
   'Callback','nowotwor_4_gui(-19)');
h_Ncirc0 = uicontrol(...
   'Style','edit', ...
   'Units','normalized', ...
   'BackgroundColor','w',...
   'ForegroundColor','k',...
   'FontSize',12,...
   'Position',[wsp_x2 wsp.y_Ncirc0 szer wys], ...
   'String',num2str(param.Ncirc0), ...
   'Value',param.Ncirc0,...
   'Callback','nowotwor_4_gui(-20)');


h_czasy = uicontrol(...
   'Style','edit', ...
   'Units','normalized', ...
   'BackgroundColor','w',...
   'ForegroundColor','k',...
   'FontSize',10,...
   'Position',[wsp_x1 wsp.y_czasy 2.65*szer wys], ...
   'String',num2str(param.czasy), ...
   'Value',param.czasy,...
   'Callback','nowotwor_4_gui(-21)');
uicontrol(...
   'style','pushbutton', ...
   'units','normalized', ...
   'position',[wsp_x1 wsp.gr_y0 szer wys], ...
   'string','SYMULACJA', ...
   'callback','nowotwor_4_gui(0)');
uicontrol(...
   'style','pushbutton', ...
   'units','normalized', ...
   'position',[wsp_x2 wsp.gr_y0 szer wys], ...
   'string','POMOCNIK', ...
   'callback','nowotwor_4_gui(-100)');

opis_pol();
figure1=gcf;
annotation1 = annotation(figure1,'rectangle',[0.625 0.6367 0.17 0.2967]);
annotation5 = annotation(figure1,'rectangle',[0.625 0.48   0.17 0.145]);
annotation6 = annotation(figure1,'rectangle',[0.625 0.2667 0.17 0.2]);
annotation7 = annotation(figure1,'rectangle',[0.625 0.18   0.17 0.07]);
annotation9 = annotation(figure1,'rectangle',[0.625 0.11   0.37 0.07]);

annotation3 = annotation(figure1,'rectangle',[0.81 0.5667 0.185 0.365]);
annotation4 = annotation(figure1,'rectangle',[0.81 0.1917 0.185 0.365]);
annotation21 = annotation(figure1,'line',[0.625 0.795],[0.18 0.18]);
set(annotation21,'Color',[0.8 0.8 0.8]);

annotation8 = annotation(...
  figure1,'textbox',...
  'Position',[0.625 0.942 0.37 0.053],...
  'HorizontalAlignment','center',...
  'String',{'PARAMETRY MODELU - opis w POMOCNIKU'},...
  'FitHeightToText','on');

dane.param = param;
dane.wsp = wsp;
dane.h = [h_alfa, h_beta, h_gamma, h_delta, h_P0,  h_Q0, h_ke,  h_kcp, h_kpc, h_xmax,...
          h_kin,  h_Km,   h_IC50,  h_kbp,   h_kout,h_Np0,h_Nd10,h_Nd20,h_Nd30,h_Ncirc0,h_czasy];
symulacja();
set(gcf,'userdata',dane); 

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
function symulacja()
dane = get(gcf,'Userdata');
p=dane.param;
xmax = p.xmax;
czasy = p.czasy;
x0=[p.yc0; p.yp0; p.P0; p.Q0; p.Np0; p.Nd10; p.Nd20; p.Nd30; p.Ncirc0]; 
T = p.czasy(end);
opcje=odeset('RelTol',1e-5);
[t,x] = ode23(@rownanie_systemu,[0,T],x0,opcje);

% Wyprowadzenie wynikow w formie graficznej:
cla;
subplot(3,1,1),    % Wykres liczby komorek
plot(t,x(:,3),'r',t,x(:,4),'b'); ha1=gca;
legend('P','Q','Location','West');
grid;
ylabel('Liczba komorek nowotworowych');

subplot(3,1,2),    % Wykres liczby krwinek
plot(t,x(:,9),'m'); ha2=gca;
grid;
ylabel('Liczba krwinek','Position',[-25 980 1]);

subplot(3,1,3),  % Wykres dozowania
n=length(czasy);
ti=zeros(1,2*n);
ti(2:2:2*n)=czasy; ti(3:2:2*n)=czasy(1:end-1);
xi=zeros(1,2*n);
x=0;
for i=1:2:2*n, 
    xi(i)=x; xi(i+1)=x;
    if x==0, x=xmax;
    else x=0;
    end
end
set(gca,'Position',[0.06, 0.06, 0.55, 0.15])
plot(ti,xi,'g'); ha3=gca;
set(gca,'Position',[0.06, 0.06, 0.55, 0.15])
xlabel('Czas {\itt} [h]');
ylabel('{\itx(t)}');
set(ha1,'Position',[0.06, 0.55, 0.55, 0.4])
set(ha2,'Position',[0.06, 0.25, 0.55, 0.25])

opis_pol();

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Funkcja obliczajaca prawa strone rown.rozniczkowego
function xp = rownanie_systemu(t,x),
dane = get(gcf,'UserData');
p=dane.param;

TPT_t=dozowanie_leku(t,p.czasy,p.xmax); 

yc=x(1); yp=x(2); P=x(3); Q=x(4); 
Np=x(5); Nd1=x(6); Nd2=x(7); Nd3=x(8); Ncirc=x(9);

dyc_dt = -(p.ke+p.kcp)*yc + p.kpc*yp + TPT_t;
dyp_dt = p.kcp*yc - p.kpc*yp;
dP_dt = (p.gamma - p.alfa - p.delta*yc)*P + p.beta*Q;
dQ_dt = p.alfa*P - p.beta*Q;
dNp_dt = (p.kin*p.Km/(p.Km+Ncirc)*p.IC50/(p.IC50+yc))*Np - p.kbp*Np;
dNd1_dt = p.kbp*(Np-Nd1);
dNd2_dt = p.kbp*(Nd1-Nd2);
dNd3_dt = p.kbp*(Nd2-Nd3);
dNcirc_dt = p.kbp*Nd3 - p.kout*Ncirc;

xp = [dyc_dt; dyp_dt; dP_dt; dQ_dt; dNp_dt; dNd1_dt; dNd2_dt; dNd3_dt; dNcirc_dt];

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%% 
% Funkcja wyznaczajaca wielkosc dawki leku w chwili t
function lek = dozowanie_leku(t,czasy,xmax),
n=length(czasy);
lek = 0;
for i=1:n,
    if t<czasy(i), break;  end,
    if lek==0, lek=xmax;
    else lek=0;
    end,
end

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Funkcja opisujaca pola edycji
function opis_pol(),
ha=axes('Position',[0 0 1 1],'Visible','off');
x=[0 1]; y=[0 1];
wy0=0.14; dwy=0.0757;
wx=0.65;
h=text(wx,wy0+10*dwy,'{\it\alpha}','FontSize',12);
h=text(wx,wy0+9*dwy,'{\it\beta}','FontSize',12);
h=text(wx,wy0+8*dwy,'{\it\gamma}','FontSize',12);
h=text(wx,wy0+7*dwy,'{\it\delta}','FontSize',12);
h=text(wx-0.02,wy0+6*dwy,'{\itP}(0)','FontSize',12,'Color','r');
h=text(wx-0.02,wy0+5*dwy,'{\itQ}(0)','FontSize',12,'Color','b');
h=text(wx-0.01,wy0+4*dwy,'{\itk_e}','FontSize',12,'Color','k');
h=text(wx-0.01,wy0+3*dwy,'{\itk_{cp}}','FontSize',12,'Color','k');
h=text(wx-0.01,wy0+2*dwy,'{\itk_{pc}}','FontSize',12,'Color','k');
h=text(wx-0.02,wy0+1*dwy,'{\itx_{max}}','FontSize',12,'Color','k');
h=text(wx,wy0+0*dwy,'{\itt_i}','FontSize',12);
wx=0.82;
h=text(wx,wy0+10*dwy,'{\itk_{in}}','FontSize',12);
h=text(wx,wy0+9*dwy,'{\itK_{m}}','FontSize',12);
h=text(wx,wy0+8*dwy,'{\itIC_{50}}','FontSize',12);
h=text(wx,wy0+7*dwy,'{\itk_{bp}}','FontSize',12);
h=text(wx,wy0+6*dwy,'{\itk_{out}}','FontSize',12,'Color','k');
h=text(wx,wy0+5*dwy,'{\itN_{p0}}','FontSize',12,'Color','k');
h=text(wx,wy0+4*dwy,'{\itN_{d10}}','FontSize',12,'Color','k');
h=text(wx,wy0+3*dwy,'{\itN_{d20}}','FontSize',12,'Color','k');
h=text(wx,wy0+2*dwy,'{\itN_{d30}}','FontSize',12,'Color','k');
h=text(wx,wy0+1*dwy,'{\itN_{circ0}}','FontSize',12,'Color','m');

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
function zmien_parametry(arg),
dane = get(gcf,'Userdata');
param = dane.param;
h = dane.h;
wsp = dane.wsp;
    switch arg,
    case -1,
        param.alfa = str2num(get(h(-arg),'String'));
        set(h(-arg),'Value',param.alfa);
    case -2,
        param.beta = str2num(get(h(-arg),'String'));
        set(h(-arg),'Value',param.beta);
    case -3,
        param.gamma = str2num(get(h(-arg),'String'));
        set(h(-arg),'Value',param.gamma);
    case -4,
        param.delta = str2num(get(h(-arg),'String'));
        set(h(-arg),'Value',param.delta);
    case -5,
        param.P0 = str2num(get(h(-arg),'String'));
        set(h(-arg),'Value',param.P0);
    case -6,
        param.Q0 = str2num(get(h(-arg),'String'));
        set(h(-arg),'Value',param.Q0);
    case -7,
        param.ke = str2num(get(h(-arg),'String'));
        set(h(-arg),'Value',param.ke);
    case -8,
        param.kcp = str2num(get(h(-arg),'String'));
        set(h(-arg),'Value',param.kcp);
    case -9,
        param.kpc = str2num(get(h(-arg),'String'));
        set(h(-arg),'Value',param.kpc);
    case -10,
        param.xmax = str2num(get(h(-arg),'String'));
        set(h(-arg),'Value',param.xmax);
    case -11,
        param.kin = str2num(get(h(-arg),'String'));
        set(h(-arg),'Value',param.kin);
    case -12,
        param.Km = str2num(get(h(-arg),'String'));
        set(h(-arg),'Value',param.Km);
    case -13,
        param.IC50 = str2num(get(h(-arg),'String'));
        set(h(-arg),'Value',param.IC50);
    case -14,
        param.kbp = str2num(get(h(-arg),'String'));
        set(h(-arg),'Value',param.kbp);
    case -15,
        param.kout = str2num(get(h(-arg),'String'));
        set(h(-arg),'Value',param.kout);
    case -16,
        param.Np0 = str2num(get(h(-arg),'String'));
        set(h(-arg),'Value',param.Np0);
    case -17,
        param.Nd10 = str2num(get(h(-arg),'String'));
        set(h(-arg),'Value',param.Nd10);
    case -18,
        param.Nd20 = str2num(get(h(-arg),'String'));
        set(h(-arg),'Value',param.Nd20);
    case -19,
        param.Nd30 = str2num(get(h(-arg),'String'));
        set(h(-arg),'Value',param.Nd30);
    case -20,
        param.Ncirc0 = str2num(get(h(-arg),'String'));
        set(h(-arg),'Value',param.Ncirc0);
    case -21,
        param.czasy = str2num(get(h(-arg),'String'));
        set(h(-arg),'Value',param.czasy);
    end
dane.param = param;
set(gcf,'Userdata',dane);

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
function pomocnik(),
figure1=figure;
set(figure1,'numbertitle','off',...%'menubar','none',...
        'Name','Opis parametrow modelu leczenia guza nowotworowego i wplywu na uklad krwiotworczy',...
        'Position',[50 0 800 800]);

annotation8 = annotation(...
  figure1,'textbox',...
  'Position',[0.03 0.05 0.6 0.9],...
  'HorizontalAlignment','Left',...
  'String',{...
  'Uwagi dotyczace edycji wartosci parametrow modelu:'...
  '- Zmiane wartosci parametru nalezy "zatwierdzic" nacisnieciem klawisza ENTER.'...
  '- Wartosci czasow {\itt_i} powinny tworzyc rosnacy ciag dowolnej liczby czasow.'...
  '- Pierwsze podawanie leku trwa od {\itt_1} do {\itt_2}, drugie od {\itt_3} do {\itt_4} itd.'...
  '- Parametry modelu sa zgrupowane w 6 ramkach.'...
  'Schemat tego podzialu jest widoczny po prawej stronie okienka.'...
  ' '...
  '1. Parametry nowotworu:'...
  '\alpha - wspolczynnik uspokajania,'...
  '\beta - wspolczynnik powrotu do dzielenia,'...
  '\gamma - wspolczynnik wzrostu,'...
  '\delta - wspolczynnik oddzialywania leku.'...
  ' '...
  '2. Poczatkowa liczebnosc komorek nowotworowych:'...
  '{\itP} - liczba komorek proliferujacych,'...
  '{\itQ} - liczba komorek uspokojonych.'...
  ' '...
  '3. Parametry transferu leku:'...
  '{\itk_e} - szybkosc naturalnego zanikania leku w osoczu,'...
  '{\itk_{cp}} - szybkosc przenikania leku ze strefy centralnej do peryferyjnej,'...
  '{\itk_{pc}} - szybkosc przenikania leku ze strefy peryferyjnej do centralnej.'...
  ' '...
  '4. Parametry strategii leczenia:'...
  '{\itx_{max}} - maksymalne dozowanie leku,'...
  '{\itt_{i}} - czasy poczatkow dozowania i odpoczynkow.'...
  ' '...
  '5. Parametry modelu ukladu krwiotworczego:'...
  '{\itk_{in}} - szybkosc wytwarzania komorek macierzystych i roznicowania ich','     w kierunku neutrofili,'...
  '{\itK_{m}} - parametr "polowicznego nasycenia",'...
  '{\itIC50} - parametr wrazliwosci ukladu krwiotworczego na lek,'...
  '{\itk_{bp}} - wspolczynnik przeksztalcania sie zawiazkow z jednej fazy w kolejna,'...
  '{\itk_{out}} - szybkosc naturalnego obumierania neutrofili.'...
  ' '...
  '6. Poczatkowa liczebnosc komorek krwi:'...
  '{\itN_{p0}} - liczba komorek niezroznicowanych,'...
  '{\itN_{d10}} - liczba mielocytow,'...
  '{\itN_{d20}} - liczba metamielocytow,'...
  '{\itN_{d30}} - liczba neutrofili-paleczek,'...
  '{\itN_{circ0}} - liczba dojrzalych neutrofili.'},...
  'FitHeightToText','on',...
  'BackgroundColor','w');

annotation1 = annotation(...
  figure1,'textbox',...
  'Position',[0.65 0.73 0.15 0.20],...
  'FitHeightToText','off',...
  'String',{'1. Parametry','   nowotworu'});
annotation2 = annotation(...
  figure1,'textbox',...
  'Position',[0.65 0.61 0.15 0.11],...
  'FitHeightToText','off',...
  'String',{'2. Poczatkowa','   liczebnosc','   komorek','   nowotworowych'});
annotation3 = annotation(...
  figure1,'textbox',...
  'Position',[0.65 0.47 0.15 0.13],...
  'FitHeightToText','off',...
  'String',{'3. Parametry','   transferu','   leku'});
annotation4 = annotation(...
  figure1,'textbox',...
  'Position',[0.65 0.36 0.15 0.10],...
  'FitHeightToText','off',...
  'String',{'4. Parametry','   strategii','   leczenia'});
annotation5 = annotation(...
  figure1,'textbox',...
  'Position',[0.83 0.68 0.15 0.25],...
  'FitHeightToText','off',...
  'String',{'5. Parametry','   modelu','   ukladu','   krwiotworczego'});
annotation6 = annotation(...
  figure1,'textbox',...
  'Position',[0.83 0.42 0.15 0.25],...
  'FitHeightToText','off',...
  'String',{'6. Poczatkowa','   liczebnosc','   komorek','   krwi'});
 
annotation8 = annotation(figure1,'line',[0.80 0.98],[0.36 0.36]);
annotation9 = annotation(figure1,'line',[0.80 0.98],[0.41 0.41]);
annotation10 = annotation(figure1,'line',[0.98 0.98],[0.36 0.41]);
annotation11 = annotation(figure1,'line',[0.80 0.80],[0.36 0.41]);
set(annotation11,'Color',[0.8 0.8 0.8]);

annotation(figure1,'arrow',[0.66 0.32],[0.89 0.78]); 
annotation(figure1,'arrow',[0.66 0.43],[0.68 0.65]);
annotation(figure1,'arrow',[0.66 0.43],[0.57 0.57]);
annotation(figure1,'arrow',[0.66 0.334],[0.426 0.45]);
annotation(figure1,'arrow',[0.89 0.39],[0.81 0.37]);
annotation(figure1,'arrow',[0.89 0.37],[0.55 0.18]);
