% epidemia_sir.m 
%
% AGH Akademia Grniczo-Hutnicza w Krakowie
% Laboratorium Biocybernetyki
%
% Wprowadzenie do modelowania cybernetycznego 
% systemw biologicznych oraz ich symulacji w rodowisku MATLAB
%
% Przykad 4.17
% Model epidemii SIR (podatny, zainfekowany, uodporniony)
%---------------------------------------------------------------------

% Dane wejciowe modelu:
t0 = 0;   % czas pocztkowy symulacji
tk = 10;  % czas kocowy symulacji
h = 0.5;  % krok rozwizywania (pocztkowy)
S0 = 0.4; % proporcja osobnikw podatnych w chwili pocztkowej (t0)
I0 = 0.6; % proporcja osobnikw zainfekowanych w chwili pocztkowej (t0)
 
% Rozwizanie rwnania rniczkowego metod przyblion Dormand-Prince
[wektor_czasu, rezultat] = ode45(@model_matematyczny_sir, [t0, tk], [S0, I0], h);
 
% Wyznaczenie proporcji osobnikw podatnych, zainfekowanych i uodpornionych
osobniki_podatne = rezultat(:, 1);
osobniki_zainfekowane = rezultat(:, 2);
osobniki_uodpornione = 1 - rezultat(:, 1) - rezultat(:, 1);
 
% Przebiegi proporcji osobnikw podatnych, zainfekowanych i uodpornionych w zalenoci od czasu
hold on;
plot(wektor_czasu, osobniki_podatne, 'r-');
plot(wektor_czasu, osobniki_zainfekowane, 'b-'); 
plot(wektor_czasu, osobniki_uodpornione, 'g-'); 
 
% Ustawienie legendy, tytuu, opisw osi oraz uwidocznienie siatki
legend('Osobniki podatne', 'Osobniki zainfekowane', 'Osobniki uodpornione');
title('Model epidemii SIR (S_0 = 0.4, I_0 = 0.6, \delta < 1)');
xlabel('Czas'); 
ylabel('Proporcja populacji'); 
grid on
