% epidemia_sirs.m 
%
% AGH Akademia Grniczo-Hutnicza w Krakowie
% Laboratorium Biocybernetyki
%
% Wprowadzenie do modelowania cybernetycznego 
% systemw biologicznych oraz ich symulacji w rodowisku MATLAB
%
% Przykad 4.18
% Model epidemii SIRS (podatny, zainfekowany, uodporniony, podatny)
%---------------------------------------------------------------------

% Dane wejciowe modelu:
t0 = 0;   % czas pocztkowy symulacji
tk = 20;  % czas kocowy symulacji
h = 0.5;  % krok rozwizywania (pocztkowy)
S0 = 0.4; % proporcja osobnikw podatnych w chwili pocztkowej (t0)
I0 = 0.6; % proporcja osobnikw zainfekowanych w chwili pocztkowej (t0)
R0 = 0.0; % proporcja osobnikw uodpornionych w chwili pocztkowej (t0)

% Rozwizanie rwnania rniczkowego metod przyblion Dormand-Prince
[wektor_czasu, rezultat] = ode45(@model_matematyczny_sirs, [t0, tk], [S0, I0, R0], h);

% Wyznaczenie proporcji osobnikow podatnych, zainfekowanych i uodpornionych
osobniki_podatne = rezultat(:, 1);
osobniki_zainfekowane = rezultat(:, 2);
osobniki_uodpornione =  rezultat(:, 3);

% Przebiegi proporcji osobnikw podatnych, zainfekowanych i uodpornionych w zalenoci od czasu
hold on;
plot(wektor_czasu, osobniki_podatne, 'r-');
plot(wektor_czasu, osobniki_zainfekowane, 'b-'); 
plot(wektor_czasu, osobniki_uodpornione, 'g-'); 

% Ustawienie legendy, tytuu, opisw osi oraz uwidocznienie siatki
legend('Osobniki podatne', 'Osobniki zainfekowane', 'Osobniki uodpornione');
title('Model epidemii SIRS (S_0 = 0.6, I_0 = 0.4, R_0 = 0, \delta < 1)');
xlabel('Czas');
ylabel('Proporcja populacji');
grid on
hold off;
